#! /usr/bin/env python3

def lag(q: int, d: int, day: int, days: int)->int:
    # return max(int(100*(f*q-d)/(q-d)), 0)
    # return max((f*q-d)/(1-f), 0.0)
    # due = max((q - d), 0.0)
    # left = 1 - f 
    # return round(((day + 1) / days) * q - d, 2)
    return round( ((q - min(d,q)) / q) * days / (days-day), 2)

    # return round((q - min(d, f * q) / (1 - f)), 2)
    # return round(due, 2), round(left, 2), round(due/left, 2) 

    # return max(int(100*(q-d)/(1-f)), 0)

late = []
late_leader = "***"
slow = []
slow_leader = "   "
summary = []

def tup2str(tup):
    return ' '.join([str(x) for x in tup]) 

days = 7
q = 14
late = []
slow = []
late_level = 2
slow_level = 1.25
print(f"for {q = }; {days = }; per-diem = {q/days:.02}")
for d in range(q):
    saved_late = False
    saved_slow = False
    for day in range(0, days):
        res = lag(q, d, day, days)
        if res >= late_level:
            if not saved_late:
                # print(f"{day = }; {days = }; {late_level = }; {slow_level = }")
                summary.append(tup2str([late_leader, day, d, res]))
                saved_late = True
                print(f"{late_leader} {day} {d=} d/q={d/q:.04} f={day/days:.04} lag = {res} vs {slow_level}, {late_level}")
        elif res >= slow_level:
            if not saved_slow:
                # print(f"{day = }; {days = }; {late_level = }; {slow_level = }")
                summary.append(tup2str([slow_leader, day, d, res]))
                saved_slow = True
                print(f"{slow_leader} {day} {d=} d/q={d/q:.04} f={day/days:.04} lag = {res} vs {slow_level}, {late_level}")
        # else:
        #     print(f"      {i} lag(s{q}, {d}, {f:.02}) = {res}")

# print(f"\nfor days = quota = {days}:\n  {'\n  '.join(summary)}\n")
# print(f"late for days = quota = {days}:\n  {'\n  '.join(late)}\n")


 


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree
from etm.__version__ import version

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'etm-dgraham'
DESCRIPTION = 'event and task manager'
URL = 'https://dagraham.github.io/etm-dgraham/'
EMAIL = 'dnlgrhm@gmail.com'
AUTHOR = 'Daniel A Graham'
REQUIRES_PYTHON = '>=3.9.0'
VERSION = version

# What packages are required for this module to be executed?
REQUIRED = [
    'icalendar>=4.0.3',
    'Jinja2>=2.10',
    'lorem>=0.1.1',
    'MarkupSafe>=1.1.0',
    'prompt-toolkit>=3.0.2',
    'Pygments>=2.5.2',
    'pyperclip>=1.7.0',
    'python-dateutil>=2.7.3',
    'ruamel.yaml>=0.15.88',
    'requests>=2.25.1',
    'six>=1.11.0',
    'style>=1.1.6',
    'tinydb>=4.0.0',
    'tinydb-serialization>=2.0.0',
    'tinydb-smartcache>=2.0.0',
    'wcwidth>=0.1.7',
    'packaging>=22.0',
]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace('-', '_').replace(' ', '_')
    with open(os.path.join(here, project_slug, '__version__.py')) as f:
        exec(f.read(), about)
    CLASSIFIERS = [
        'Development Status :: 2 - Pre-Alpha',
    ]
else:
    about['__version__'] = VERSION
    if 'a' in VERSION:
        CLASSIFIERS = [
            'Development Status :: 3 - Alpha',
        ]
    elif 'b' in VERSION:
        CLASSIFIERS = [
            'Development Status :: 4 - Beta',
        ]
    else:
        CLASSIFIERS = [
            'Development Status :: 5 - Production/Stable',
        ]

    CLASSIFIERS.extend(
        [
            'Environment :: Console',
            'Intended Audience :: End Users/Desktop',
            'License :: OSI Approved :: GNU General Public License (GPL)',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3.9',
            'Programming Language :: Python :: 3.10',
            'Programming Language :: Python :: 3.11',
            'Programming Language :: Python :: 3.12',
            'Programming Language :: Python :: Implementation :: CPython',
            'Programming Language :: Python :: Implementation :: PyPy',
            'Topic :: Office/Business',
            'Topic :: Office/Business :: News/Diary',
            'Topic :: Office/Business :: Scheduling',
        ]
    )


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError as e:
            print('error removing dist tree:', e)

        self.status('Building Source and Wheel (universal) distribution…')
        os.system(
            '{0} setup.py sdist bdist_wheel --universal'.format(sys.executable)
        )

        self.status('Uploading the package to PyPI via Twine…')
        os.system(
            'twine upload --verbose --repository-url https://upload.pypi.org/legacy/ dist/*'
        )

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    # packages=['etm'],
    packages=find_packages(exclude=('tests', 'test', 'tmp')),
    # If your package is a single module, use this instead of 'packages':
    # py_modules=['mypackage'],
    entry_points={
        'console_scripts': [
            'etm=etm.__main__:main',
            'etm+=etm.__main__:inbasket',
        ],
    },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license='GPL',
    classifiers=CLASSIFIERS,
    cmdclass={
        'upload': UploadCommand,
    },
)
